# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata
from .create_multi_response_bundle_entry_item import CreateMultiResponseBundleEntryItem


class CreateMultiResponseBundle(UniversalBaseModel):
    """
    FHIR transaction Bundle containing all extracted resources
    """

    resource_type: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="resourceType")] = None
    type: typing.Optional[str] = None
    entry: typing.Optional[typing.List[CreateMultiResponseBundleEntryItem]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
