# This file was auto-generated by Fern from our API Definition.

import typing

ExtractRequestConfigChunkingMethod = typing.Union[
    typing.Literal["none", "sentences", "paragraphs", "topics"], typing.Any
]
