# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class WorkflowConfig(UniversalBaseModel):
    fhir_provider_ids: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    FHIR provider IDs for executing workflow steps
    """

    dynamic_generation: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether to use dynamic lang2fhir generation instead of pre-populated templates
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
