# This file was auto-generated by Fern from our API Definition.

import typing

Role = typing.Union[
    typing.Literal[
        "SmartV1Admin",
        "SmartV1Read",
        "SmartV1Write",
        "SmartV2Admin",
        "SmartV2Read",
        "SmartV2Write",
        "USCDISmartV1Admin",
        "USCDISmartV1Read",
        "USCDISmartV1Write",
        "USCDISmartV2Admin",
        "USCDISmartV2Read",
        "USCDISmartV2Write",
        "CernerSmartV1Admin",
        "CernerSmartV1Read",
        "CernerSmartV1Write",
        "CernerSmartV2Admin",
        "CernerSmartV2Read",
        "CernerSmartV2Write",
    ],
    typing.Any,
]
