# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class SummaryTemplate(UniversalBaseModel):
    id: typing.Optional[str] = None
    user_id: typing.Optional[str] = None
    name: typing.Optional[str] = None
    description: typing.Optional[str] = None
    template: typing.Optional[str] = pydantic.Field(default=None)
    """
    Template with {{resource.field}} placeholders
    """

    target_resources: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    List of FHIR resource types/profiles
    """

    mode: typing.Optional[str] = pydantic.Field(default=None)
    """
    Template mode (stored value)
    """

    metadata: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = None
    created_at: typing.Optional[dt.datetime] = None
    updated_at: typing.Optional[dt.datetime] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
