# This file was auto-generated by Fern from our API Definition.

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .auth.client import AsyncAuthClient, AuthClient
from .raw_client import AsyncRawAuthtokenClient, RawAuthtokenClient


class AuthtokenClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawAuthtokenClient(client_wrapper=client_wrapper)
        self.auth = AuthClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawAuthtokenClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawAuthtokenClient
        """
        return self._raw_client


class AsyncAuthtokenClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawAuthtokenClient(client_wrapper=client_wrapper)
        self.auth = AsyncAuthClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawAuthtokenClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawAuthtokenClient
        """
        return self._raw_client
