# This file was auto-generated by Fern from our API Definition.

import typing

from .fhir_bundle import FhirBundle
from .fhir_resource import FhirResource

CreateSummaryRequestFhirResources = typing.Union[FhirResource, FhirBundle]
