# This file was auto-generated by Fern from our API Definition.

import typing

import httpx
from .agent.client import AgentClient, AsyncAgentClient
from .authtoken.client import AsyncAuthtokenClient, AuthtokenClient
from .cohort.client import AsyncCohortClient, CohortClient
from .construe.client import AsyncConstrueClient, ConstrueClient
from .core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .environment import phenomlEnvironment
from .fhir.client import AsyncFhirClient, FhirClient
from .fhir_provider.client import AsyncFhirProviderClient, FhirProviderClient
from .lang2fhir.client import AsyncLang2FhirClient, Lang2FhirClient
from .summary.client import AsyncSummaryClient, SummaryClient
from .tools.client import AsyncToolsClient, ToolsClient
from .workflows.client import AsyncWorkflowsClient, WorkflowsClient


class phenoml:
    """
    Use this class to access the different functions within the SDK. You can instantiate any number of clients with different configuration that will propagate to these functions.

    Parameters
    ----------
    base_url : typing.Optional[str]
        The base url to use for requests from the client.

    environment : phenomlEnvironment
        The environment to use for requests from the client. from .environment import phenomlEnvironment



        Defaults to phenomlEnvironment.DEFAULT



    token : typing.Union[str, typing.Callable[[], str]]
    headers : typing.Optional[typing.Dict[str, str]]
        Additional headers to send with every request.

    timeout : typing.Optional[float]
        The timeout to be used, in seconds, for requests. By default the timeout is 60 seconds, unless a custom httpx client is used, in which case this default is not enforced.

    follow_redirects : typing.Optional[bool]
        Whether the default httpx client follows redirects or not, this is irrelevant if a custom httpx client is passed in.

    httpx_client : typing.Optional[httpx.Client]
        The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.

    Examples
    --------
    from phenoml import phenoml

    client = phenoml(
        token="YOUR_TOKEN",
    )
    """

    def __init__(
        self,
        *,
        base_url: typing.Optional[str] = None,
        environment: phenomlEnvironment = phenomlEnvironment.DEFAULT,
        token: typing.Union[str, typing.Callable[[], str]],
        headers: typing.Optional[typing.Dict[str, str]] = None,
        timeout: typing.Optional[float] = None,
        follow_redirects: typing.Optional[bool] = True,
        httpx_client: typing.Optional[httpx.Client] = None,
    ):
        _defaulted_timeout = (
            timeout if timeout is not None else 60 if httpx_client is None else httpx_client.timeout.read
        )
        self._client_wrapper = SyncClientWrapper(
            base_url=_get_base_url(base_url=base_url, environment=environment),
            token=token,
            headers=headers,
            httpx_client=httpx_client
            if httpx_client is not None
            else httpx.Client(timeout=_defaulted_timeout, follow_redirects=follow_redirects)
            if follow_redirects is not None
            else httpx.Client(timeout=_defaulted_timeout),
            timeout=_defaulted_timeout,
        )
        self.agent = AgentClient(client_wrapper=self._client_wrapper)
        self.authtoken = AuthtokenClient(client_wrapper=self._client_wrapper)
        self.cohort = CohortClient(client_wrapper=self._client_wrapper)
        self.construe = ConstrueClient(client_wrapper=self._client_wrapper)
        self.fhir = FhirClient(client_wrapper=self._client_wrapper)
        self.fhir_provider = FhirProviderClient(client_wrapper=self._client_wrapper)
        self.lang2fhir = Lang2FhirClient(client_wrapper=self._client_wrapper)
        self.summary = SummaryClient(client_wrapper=self._client_wrapper)
        self.tools = ToolsClient(client_wrapper=self._client_wrapper)
        self.workflows = WorkflowsClient(client_wrapper=self._client_wrapper)


class Asyncphenoml:
    """
    Use this class to access the different functions within the SDK. You can instantiate any number of clients with different configuration that will propagate to these functions.

    Parameters
    ----------
    base_url : typing.Optional[str]
        The base url to use for requests from the client.

    environment : phenomlEnvironment
        The environment to use for requests from the client. from .environment import phenomlEnvironment



        Defaults to phenomlEnvironment.DEFAULT



    token : typing.Union[str, typing.Callable[[], str]]
    headers : typing.Optional[typing.Dict[str, str]]
        Additional headers to send with every request.

    timeout : typing.Optional[float]
        The timeout to be used, in seconds, for requests. By default the timeout is 60 seconds, unless a custom httpx client is used, in which case this default is not enforced.

    follow_redirects : typing.Optional[bool]
        Whether the default httpx client follows redirects or not, this is irrelevant if a custom httpx client is passed in.

    httpx_client : typing.Optional[httpx.AsyncClient]
        The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.

    Examples
    --------
    from phenoml import Asyncphenoml

    client = Asyncphenoml(
        token="YOUR_TOKEN",
    )
    """

    def __init__(
        self,
        *,
        base_url: typing.Optional[str] = None,
        environment: phenomlEnvironment = phenomlEnvironment.DEFAULT,
        token: typing.Union[str, typing.Callable[[], str]],
        headers: typing.Optional[typing.Dict[str, str]] = None,
        timeout: typing.Optional[float] = None,
        follow_redirects: typing.Optional[bool] = True,
        httpx_client: typing.Optional[httpx.AsyncClient] = None,
    ):
        _defaulted_timeout = (
            timeout if timeout is not None else 60 if httpx_client is None else httpx_client.timeout.read
        )
        self._client_wrapper = AsyncClientWrapper(
            base_url=_get_base_url(base_url=base_url, environment=environment),
            token=token,
            headers=headers,
            httpx_client=httpx_client
            if httpx_client is not None
            else httpx.AsyncClient(timeout=_defaulted_timeout, follow_redirects=follow_redirects)
            if follow_redirects is not None
            else httpx.AsyncClient(timeout=_defaulted_timeout),
            timeout=_defaulted_timeout,
        )
        self.agent = AsyncAgentClient(client_wrapper=self._client_wrapper)
        self.authtoken = AsyncAuthtokenClient(client_wrapper=self._client_wrapper)
        self.cohort = AsyncCohortClient(client_wrapper=self._client_wrapper)
        self.construe = AsyncConstrueClient(client_wrapper=self._client_wrapper)
        self.fhir = AsyncFhirClient(client_wrapper=self._client_wrapper)
        self.fhir_provider = AsyncFhirProviderClient(client_wrapper=self._client_wrapper)
        self.lang2fhir = AsyncLang2FhirClient(client_wrapper=self._client_wrapper)
        self.summary = AsyncSummaryClient(client_wrapper=self._client_wrapper)
        self.tools = AsyncToolsClient(client_wrapper=self._client_wrapper)
        self.workflows = AsyncWorkflowsClient(client_wrapper=self._client_wrapper)


def _get_base_url(*, base_url: typing.Optional[str] = None, environment: phenomlEnvironment) -> str:
    if base_url is not None:
        return base_url
    elif environment is not None:
        return environment.value
    else:
        raise Exception("Please pass in either base_url or environment to construct the client")
