# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .mcp_server_response_data import McpServerResponseData


class McpServerResponse(UniversalBaseModel):
    success: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether the MCP server was created successfully
    """

    message: typing.Optional[str] = pydantic.Field(default=None)
    """
    Status message
    """

    data: typing.Optional[McpServerResponseData] = pydantic.Field(default=None)
    """
    MCP server data
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
