# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class FhirProviderSandboxInfo(UniversalBaseModel):
    """
    Information returned for sandbox FHIR providers.
    """

    id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Unique identifier for the FHIR provider
    """

    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    Display name for the FHIR provider
    """

    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    Optional description of the FHIR provider
    """

    provider: typing.Optional[typing.Literal["sandbox"]] = pydantic.Field(default=None)
    """
    Provider type (always "sandbox" for this schema)
    """

    is_active: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether the FHIR provider is active
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
